pub struct TradeId(/* private fields */);Expand description
Represents a valid trade match ID (assigned by a trading venue).
The unique ID assigned to the trade entity once it is received or matched by the venue or central counterparty.
Can correspond to the TradeID <1003> field of the FIX protocol.
Maximum length is 36 characters.
Implementations
Sourceimpl TradeId
impl TradeId
Sourcepub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
pub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
Creates a new TradeId instance with correctness checking.
Maximum length is 36 characters.
Errors
Returns an error if:
valueis an invalid string (e.g., is empty or contains non-ASCII characters).valuelength exceeds 36 characters.
Notes
PyO3 requires a Result type for proper error handling and stacktrace printing in Python.
Sourcepub fn from_bytes(bytes: &[u8]) -> CorrectnessResult<Self>
pub fn from_bytes(bytes: &[u8]) -> CorrectnessResult<Self>